/*
 * pFlashDemo.c
 *
 *  Created on: 26  2019 .
 *      Author: 037512
 */

#include <stdio.h>
#include <string.h>
#include <Cpu/Std/IfxCpu.h>
#include "Ifx_Assert.h"
#include "pFlashDemo.h"


#define FLASHDEMO_PFLASH_PAGE_LENGTH 0x20          /**< \brief P Flash Page Length */

#define FLASHDEMO_PFLASH_SECTOR_NO   27            /**< \brief P Flash Sector to be erased & Programmed */
#define FLASHDEMO_PFLASH_START_PAGE  0             /**< \brief P Flash Programming starts from this page */
#define FLASHDEMO_PFLASH_NO_OF_PAGES 5             /**< \brief P Flash - No of pages to be programmed */

App_Pflash g_Pflash; /**< \brief PFlash global data */
char returnMessage[128];
static char* runDemo();
void delaySimple(uint32 cycle);

static void PFlashErase(uint32 flash, uint32 sector_addr)
{
	uint16 endinitSfty_pw;
	endinitSfty_pw = IfxScuWdt_getSafetyWatchdogPasswordInline();

	/* Erase the sector */
	IfxScuWdt_clearSafetyEndinitInline(endinitSfty_pw);
	IfxFlash_eraseSector(sector_addr);
	IfxScuWdt_setSafetyEndinitInline(endinitSfty_pw);

	/* wait until unbusy */
	IfxFlash_waitUnbusy(flash, g_Pflash.flashType);

}

static void PFlashProgram(uint32 flash, uint32 sector_addr, uint32 start_page, uint32 no_of_pages)
{
    uint32 offset;
    uint32 page;
    uint16 endinitSfty_pw;
    endinitSfty_pw = IfxScuWdt_getSafetyWatchdogPasswordInline();

    /* program the given no of pages */
    for (page = start_page; page < no_of_pages; ++page)
    {
        uint32 pageAddr = sector_addr + page * FLASHDEMO_PFLASH_PAGE_LENGTH;
        IfxFlash_enterPageMode(pageAddr);

        /* wait until unbusy */
        IfxFlash_waitUnbusy(flash, g_Pflash.flashType);
        /* write 32 bytes (8 doublewords) into assembly buffer */
        for (offset = 0; offset < FLASHDEMO_PFLASH_PAGE_LENGTH; offset += 8)
        {
        	IfxFlash_loadPage2X32(pageAddr, pageAddr, offset);
        	//IfxFlash_loadPage2X32(pageAddr, 0xabbc0011, offset);
        }
        /* write page */
        IfxScuWdt_clearSafetyEndinitInline(endinitSfty_pw);
        IfxFlash_writePage(pageAddr);
        IfxScuWdt_setSafetyEndinitInline(endinitSfty_pw);
        /* wait until unbusy */
        IfxFlash_waitUnbusy(flash, g_Pflash.flashType);
    }
}

/** \brief Demo init API
 *
 * This function is called from main during initialization phase
 */
static void programIfxFlashDemo_init(void)
{
    /* Initialise the P Flash global data */
    g_Pflash.sector        = FLASHDEMO_PFLASH_SECTOR_NO;
    g_Pflash.startPage     = FLASHDEMO_PFLASH_START_PAGE;
    g_Pflash.numberOfPages = FLASHDEMO_PFLASH_NO_OF_PAGES;
    g_Pflash.flashType     = IfxFlash_FlashType_P1;
}

App_Pflash* createProgramFlashDemo()
{
	programIfxFlashDemo_init();
	g_Pflash.command.runDemo = runDemo;

	return &g_Pflash;
}

char* runDemo()
{
	uint32  errors      = 0;
    uint32  offset;
    uint32  page        = 0;
    uint32  flash       = 1;
	uint32  sector_addr = IfxFlash_pFlashTableLog[g_Pflash.sector].start;
    /* disable interrupts */
    boolean interruptState = IfxCpu_disableInterrupts();
	
    PFlashErase(flash, sector_addr);
	PFlashProgram(flash, sector_addr, g_Pflash.startPage, g_Pflash.numberOfPages);
	
	/* enable interrupts again */
    IfxCpu_restoreInterrupts(interruptState);

    /* Verify the programmed data */
    for (page = g_Pflash.startPage; page < g_Pflash.numberOfPages; ++page)
    {
        uint32          pageAddr = sector_addr + page * FLASHDEMO_PFLASH_PAGE_LENGTH;
        volatile uint8 *addr     = (uint8 *)pageAddr;

        for (offset = 0; offset < FLASHDEMO_PFLASH_PAGE_LENGTH; offset += 8)
        {
            if (!((pageAddr == *((uint32 *)(addr + offset))) &&
                  (addr[offset + 4] == offset)))
            {
                errors++;
            }
        }
    }

    IFX_ASSERT(IFX_VERBOSE_LEVEL_ERROR, errors == 0);
    return returnMessage;
}

void delaySimple(uint32 cycle)
{
	while(cycle)
	{
		cycle--;
	}
}

